@@ -1,9 +1,11 @@
 from collectd_rest import models, serializers, renderers
 from rest_framework import viewsets
-from rest_framework.renderers import JSONRenderer
-from rest_framework.decorators import detail_route
 from rest_framework.settings import api_settings
-from django.http import HttpResponse
+
+class GraphGranularityViewSet(viewsets.ModelViewSet):
+	queryset = models.GraphGranularity.objects.all()
+	serializer_class = serializers.GraphGranularitySerializer
+	lookup_field = 'name'
 
 class GraphGroupViewSet(viewsets.ModelViewSet):
 	queryset = models.GraphGroup.objects.all()
@@ -11,6 +13,6 @@ class GraphGroupViewSet(viewsets.ModelViewSet):
 	lookup_field = 'name'
 
 class GraphViewSet(viewsets.ModelViewSet):
-	queryset = models.Graph.objects.all()
+	queryset = models.Graph.objects.prefetch_related('granularity').all()
 	serializer_class = serializers.GraphSerializer
 	renderer_classes = api_settings.DEFAULT_RENDERER_CLASSES + [renderers.PNGRenderer, renderers.SVGRenderer, ]
