@@ -1,4 +1,7 @@
-from django.core.urlresolvers import reverse
+try:
+	from django.urls import reverse
+except ImportError:
+	from django.core.urlresolvers import reverse
 from django.test import TestCase
 from rest_framework import status
 from rest_framework.test import APIClient
